@@ -3,7 +3,19 @@ from .firewall import FirewallMixin
 from .firewall_alias import FirewallAliasMixin
 from .interface import InterfaceMixin
 from .routing import RoutingMixin
-from .service  import ServiceMixin
+from .service import ServiceMixin
 from .status import StatusMixin
 from .system import SystemMixin
 from .user import UserMixin
+
+__all__ = [
+    "DNSMixin",
+    "FirewallMixin",
+    "FirewallAliasMixin",
+    "InterfaceMixin",
+    "RoutingMixin",
+    "ServiceMixin",
+    "StatusMixin",
+    "SystemMixin",
+    "UserMixin",
+]
